@@ -1,4 +1,4 @@
-# $Id: ZapListings.pm,v 1.71 2003/11/03 20:50:29 epaepa Exp $
+# $Id: ZapListings.pm,v 1.76 2003/12/07 22:28:56 epaepa Exp $
 
 #
 # Special thanks to Stephen Bain for helping me play catch-up with
@@ -152,7 +152,7 @@ sub new
 				  env_proxy => 1,
 				  timeout => 180);
     bless ($self, $class);
-    $self->agent('xmltv/0.5.21');
+    $self->agent('xmltv/0.5.25');
     return $self;
 }
 
@@ -875,10 +875,10 @@ sub initGeoCodeAndGetProvidersList($$)
 
     while ( $content=~s/<SELECT(.*)(?=<\/SELECT>)//ios ) {
         my $options=$1;
-        while ( $options=~s/<OPTION value="(\d+)">([^<]+)<\/OPTION>//ios ) {
+        while ( $options=~s/<OPTION value="(\d+)"\s*>([^<]+)<\/OPTION>//ios ) {
 	    my $p;
 	    $p->{id}=$1;
-	    $p->{description}=$2;
+	    $p->{description}=massageText($2);
             #main::debugMessage("provider $1 ($2)\n";
 	    push(@{$self->{ProviderList}->{$self->{GeoCode}}}, $p);
         }
